@@ -583,6 +583,25 @@ public class FormatData_nb extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat", "tidssone for {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 tusen",
+                    "00 tusen",
+                    "000 tusen",
+                    "0 million",
+                    "00 million",
+                    "000 million",
+                    "0 milliard",
+                    "00 milliard",
+                    "000 milliard",
+                    "0 billion",
+                    "00 billioner",
+                    "000 billioner",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -921,6 +940,25 @@ public class FormatData_nb extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0k",
+                    "00k",
+                    "000k",
+                    "0\u00a0mill",
+                    "00\u00a0mill",
+                    "000\u00a0mill",
+                    "0\u00a0mrd",
+                    "00\u00a0mrd",
+                    "000\u00a0mrd",
+                    "0\u00a0bill",
+                    "00\u00a0bill",
+                    "000\u00a0bill",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "sommertid \u2013 {0}" },
             { "DatePatterns",
